# rowan_ds_tools

A suite of commonly used DS functions/classes

for installation please check out the project's [pypi page](https://pypi.org/project/rowan-ds-tools/) or install with:   
`pip install rowan-ds-tools`


